MySQL — SQLAlchemy 0.5.6 Documentation

# SQLAlchemy 0.5.6 Documentation

Search:
Version: 0.5.6 Last Updated: 09/13/2009 10:45:11

# MySQL

Support for the MySQL database.

## Overview

For normal SQLAlchemy usage, importing this module is unnecessary. It will be loaded on-demand when a MySQL connection is needed. The generic column types like `String` and `Integer` will automatically be adapted to the optimal matching MySQL column type.

But if you would like to use one of the MySQL-specific or enhanced column types when creating tables with your `Table` definitions, then you will need to import them from this module:

    from sqlalchemy.databases import mysql

    Table('mytable', metadata,
          Column('id', Integer, primary_key=True),
          Column('ittybittyblob', mysql.MSTinyBlob),
          Column('biggy', mysql.MSBigInteger(unsigned=True)))

All standard MySQL column types are supported. The OpenGIS types are available for use via table reflection but have no special support or mapping to Python classes. If you’re using these types and have opinions about how OpenGIS can be smartly integrated into SQLAlchemy please join the mailing list!

## Supported Versions and Features

SQLAlchemy supports 6 major MySQL versions: 3.23, 4.0, 4.1, 5.0, 5.1 and 6.0, with capabilities increasing with more modern servers.

Versions 4.1 and higher support the basic SQL functionality that SQLAlchemy uses in the ORM and SQL expressions. These versions pass the applicable tests in the suite 100%. No heroic measures are taken to work around major missing SQL features- if your server version does not support sub-selects, for example, they won’t work in SQLAlchemy either.

Currently, the only DB-API driver supported is MySQL-Python (also referred to as MySQLdb). Either 1.2.1 or 1.2.2 are recommended. The alpha, beta and gamma releases of 1.2.1 and 1.2.2 should be avoided. Support for Jython and IronPython is planned.

Feature | Minimum Version
--- | ---
sqlalchemy.orm | 4.1.1
Table Reflection | 3.23.x
DDL Generation | 4.1.1
utf8/Full Unicode Connections | 4.1.1
Transactions | 3.23.15
Two-Phase Transactions | 5.0.3
Nested Transactions | 5.0.3

See the official MySQL documentation for detailed information about features supported in any given server release.

## Character Sets

Many MySQL server installations default to a `latin1` encoding for client connections. All data sent through the connection will be converted into `latin1`, even if you have `utf8` or another character set on your tables and columns. With versions 4.1 and higher, you can change the connection character set either through server configuration or by including the `charset` parameter in the URL used for `create_engine`. The `charset` option is passed through to MySQL-Python and has the side-effect of also enabling `use_unicode` in the driver by default. For regular encoded strings, also pass `use_unicode=0` in the connection arguments:

    # set client encoding to utf8; all strings come back as unicode
    create_engine('mysql:///mydb?charset=utf8')

    # set client encoding to utf8; all strings come back as utf8 str
    create_engine('mysql:///mydb?charset=utf8&use_unicode=0')

## Storage Engines

Most MySQL server installations have a default table type of `MyISAM`, a non-transactional table type. During a transaction, non-transactional storage engines do not participate and continue to store table changes in autocommit mode. For fully atomic transactions, all participating tables must use a transactional engine such as `InnoDB`, `Falcon`, `SolidDB`, PBXT, etc.

Storage engines can be elected when creating tables in SQLAlchemy by supplying a `mysql_engine='whatever'` to the `Table` constructor. Any MySQL table creation option can be specified in this syntax:

    Table('mytable', metadata,
          Column('data', String(32)),
          mysql_engine='InnoDB',
          mysql_charset='utf8'
         )

## Keys

Not all MySQL storage engines support foreign keys. For `MyISAM` and similar engines, the information loaded by table reflection will not include foreign keys. For these tables, you may supply a `ForeignKeyConstraint` at reflection time:

    Table('mytable', metadata,
          ForeignKeyConstraint(['other_id'], ['othertable.other_id']),
          autoload=True
         )

When creating tables, SQLAlchemy will automatically set `AUTO_INCREMENT`` on an integer primary key column:

    >>> t = Table('mytable', metadata,
    ...   Column('mytable_id', Integer, primary_key=True)
    ... )
    >>> t.create()
    CREATE TABLE mytable (
            id INTEGER NOT NULL AUTO_INCREMENT,
            PRIMARY KEY (id)
    )

You can disable this behavior by supplying `autoincrement=False` to the `Column`. This flag can also be used to enable auto-increment on a secondary column in a multi-column key for some storage engines:

    Table('mytable', metadata,
          Column('gid', Integer, primary_key=True, autoincrement=False),
          Column('id', Integer, primary_key=True)
         )

## SQL Mode

MySQL SQL modes are supported. Modes that enable `ANSI_QUOTES` (such as `ANSI`) require an engine option to modify SQLAlchemy’s quoting style. When using an ANSI-quoting mode, supply `use_ansiquotes=True` when creating your `Engine`:

    create_engine('mysql://localhost/test', use_ansiquotes=True)

This is an engine-wide option and is not toggleable on a per-connection basis. SQLAlchemy does not presume to `SET sql_mode` for you with this option. For the best performance, set the quoting style server-wide in `my.cnf` or by supplying `--sql-mode` to `mysqld`. You can also use a `sqlalchemy.pool.Pool` listener hook to issue a `SET SESSION sql_mode='...'` on connect to configure each connection.

If you do not specify `use_ansiquotes`, the regular MySQL quoting style is used by default.

If you do issue a `SET sql_mode` through SQLAlchemy, the dialect must be updated if the quoting style is changed. Again, this change will affect all connections:

    connection.execute('SET sql_mode="ansi"')
    connection.dialect.use_ansiquotes = True

## MySQL SQL Extensions

Many of the MySQL SQL extensions are handled through SQLAlchemy’s generic function and operator support:

    table.select(table.c.password==func.md5('plaintext'))
    table.select(table.c.username.op('regexp')('^[a-d]'))

And of course any valid MySQL statement can be executed as a string as well.

Some limited direct support for MySQL extensions to SQL is currently available.

> - SELECT pragma:

>       select(..., prefixes=['HIGH_PRIORITY', 'SQL_SMALL_RESULT'])

> - UPDATE with LIMIT:

>       update(..., mysql_limit=10)

## Troubleshooting

If you have problems that seem server related, first check that you are using the most recent stable MySQL-Python package available. The Database Notes page on the wiki at http://www.sqlalchemy.org is a good resource for timely information affecting MySQL in SQLAlchemy.

## MySQL Column Types

class `sqlalchemy.databases.mysql.` `MSNumeric`(precision=10, scale=2, asdecimal=True, **kw)

  Bases: `sqlalchemy.types.Numeric`, `sqlalchemy.databases.mysql._NumericType`

  MySQL NUMERIC type.

  `__init__`(precision=10, scale=2, asdecimal=True, **kw)

    Construct a NUMERIC.

    Parameters: | precision – Total digits in this number. If scale and precision are both None, values are stored to limits allowed by the server. scale – The number of digits after the decimal point. unsigned – a boolean, optional. zerofill – Optional. If true, values will be stored as strings left-padded with zeros. Note that this does not effect the values returned by the underlying database API, which continue to be numeric.

class `sqlalchemy.databases.mysql.` `MSDecimal`(precision=10, scale=2, asdecimal=True, **kw)

  Bases: `sqlalchemy.databases.mysql.MSNumeric`

  MySQL DECIMAL type.

  `__init__`(precision=10, scale=2, asdecimal=True, **kw)

    Construct a DECIMAL.

    Parameters: | precision – Total digits in this number. If scale and precision are both None, values are stored to limits allowed by the server. scale – The number of digits after the decimal point. unsigned – a boolean, optional. zerofill – Optional. If true, values will be stored as strings left-padded with zeros. Note that this does not effect the values returned by the underlying database API, which continue to be numeric.

class `sqlalchemy.databases.mysql.` `MSDouble`(precision=None, scale=None, asdecimal=True, **kw)

  Bases: `sqlalchemy.types.Float`, `sqlalchemy.databases.mysql._NumericType`

  MySQL DOUBLE type.

  `__init__`(precision=None, scale=None, asdecimal=True, **kw)

    Construct a DOUBLE.

    Parameters: | precision – Total digits in this number. If scale and precision are both None, values are stored to limits allowed by the server. scale – The number of digits after the decimal point. unsigned – a boolean, optional. zerofill – Optional. If true, values will be stored as strings left-padded with zeros. Note that this does not effect the values returned by the underlying database API, which continue to be numeric.

class `sqlalchemy.databases.mysql.` `MSReal`(precision=None, scale=None, asdecimal=True, **kw)

  Bases: `sqlalchemy.databases.mysql.MSDouble`

  MySQL REAL type.

  `__init__`(precision=None, scale=None, asdecimal=True, **kw)

    Construct a REAL.

    Parameters: | precision – Total digits in this number. If scale and precision are both None, values are stored to limits allowed by the server. scale – The number of digits after the decimal point. unsigned – a boolean, optional. zerofill – Optional. If true, values will be stored as strings left-padded with zeros. Note that this does not effect the values returned by the underlying database API, which continue to be numeric.

class `sqlalchemy.databases.mysql.` `MSFloat`(precision=None, scale=None, asdecimal=False, **kw)

  Bases: `sqlalchemy.types.Float`, `sqlalchemy.databases.mysql._NumericType`

  MySQL FLOAT type.

  `__init__`(precision=None, scale=None, asdecimal=False, **kw)

    Construct a FLOAT.

    Parameters: | precision – Total digits in this number. If scale and precision are both None, values are stored to limits allowed by the server. scale – The number of digits after the decimal point. unsigned – a boolean, optional. zerofill – Optional. If true, values will be stored as strings left-padded with zeros. Note that this does not effect the values returned by the underlying database API, which continue to be numeric.

class `sqlalchemy.databases.mysql.` `MSInteger`(display_width=None, **kw)

  Bases: `sqlalchemy.types.Integer`, `sqlalchemy.databases.mysql._NumericType`

  MySQL INTEGER type.

  `__init__`(display_width=None, **kw)

    Construct an INTEGER.

    Parameters: | display_width – Optional, maximum display width for this number. unsigned – a boolean, optional. zerofill – Optional. If true, values will be stored as strings left-padded with zeros. Note that this does not effect the values returned by the underlying database API, which continue to be numeric.

class `sqlalchemy.databases.mysql.` `MSBigInteger`(display_width=None, **kw)

  Bases: `sqlalchemy.databases.mysql.MSInteger`

  MySQL BIGINTEGER type.

  `__init__`(display_width=None, **kw)

    Construct a BIGINTEGER.

    Parameters: | display_width – Optional, maximum display width for this number. unsigned – a boolean, optional. zerofill – Optional. If true, values will be stored as strings left-padded with zeros. Note that this does not effect the values returned by the underlying database API, which continue to be numeric.

class `sqlalchemy.databases.mysql.` `MSMediumInteger`(display_width=None, **kw)

  Bases: `sqlalchemy.databases.mysql.MSInteger`

  MySQL MEDIUMINTEGER type.

  `__init__`(display_width=None, **kw)

    Construct a MEDIUMINTEGER

    Parameters: | display_width – Optional, maximum display width for this number. unsigned – a boolean, optional. zerofill – Optional. If true, values will be stored as strings left-padded with zeros. Note that this does not effect the values returned by the underlying database API, which continue to be numeric.

class `sqlalchemy.databases.mysql.` `MSTinyInteger`(display_width=None, **kw)

  Bases: `sqlalchemy.databases.mysql.MSInteger`

  MySQL TINYINT type.

  `__init__`(display_width=None, **kw)

    Construct a TINYINT.

    Note: following the usual MySQL conventions, TINYINT(1) columns reflected during Table(..., autoload=True) are treated as Boolean columns.

    Parameters: | display_width – Optional, maximum display width for this number. unsigned – a boolean, optional. zerofill – Optional. If true, values will be stored as strings left-padded with zeros. Note that this does not effect the values returned by the underlying database API, which continue to be numeric.

class `sqlalchemy.databases.mysql.` `MSSmallInteger`(display_width=None, **kw)

  Bases: `sqlalchemy.types.SmallInteger`, `sqlalchemy.databases.mysql.MSInteger`

  MySQL SMALLINTEGER type.

  `__init__`(display_width=None, **kw)

    Construct a SMALLINTEGER.

    Parameters: | display_width – Optional, maximum display width for this number. unsigned – a boolean, optional. zerofill – Optional. If true, values will be stored as strings left-padded with zeros. Note that this does not effect the values returned by the underlying database API, which continue to be numeric.

class `sqlalchemy.databases.mysql.` `MSBit`(length=None)

  Bases: `sqlalchemy.types.TypeEngine`

  MySQL BIT type.

  This type is for MySQL 5.0.3 or greater for MyISAM, and 5.0.5 or greater for MyISAM, MEMORY, InnoDB and BDB. For older versions, use a MSTinyInteger() type.

  `__init__`(length=None)

    Construct a BIT.

    Parameter: | length – Optional, number of bits.

class `sqlalchemy.databases.mysql.` `MSDateTime`(timezone=False)

  Bases: `sqlalchemy.types.DateTime`

  MySQL DATETIME type.

  `__init__`(timezone=False)

class `sqlalchemy.databases.mysql.` `MSDate`(*args, **kwargs)

  Bases: `sqlalchemy.types.Date`

  MySQL DATE type.

  `__init__`(*args, **kwargs)

class `sqlalchemy.databases.mysql.` `MSTime`(timezone=False)

  Bases: `sqlalchemy.types.Time`

  MySQL TIME type.

  `__init__`(timezone=False)

class `sqlalchemy.databases.mysql.` `MSTimeStamp`(timezone=False)

  Bases: `sqlalchemy.types.TIMESTAMP`

  MySQL TIMESTAMP type.

  To signal the orm to automatically re-select modified rows to retrieve the updated timestamp, add a `server_default` to your `Column` specification:

      from sqlalchemy.databases import mysql
      Column('updated', mysql.MSTimeStamp,
             server_default=sql.text('CURRENT_TIMESTAMP')
            )

  The full range of MySQL 4.1+ TIMESTAMP defaults can be specified in the the default:

      server_default=sql.text('CURRENT TIMESTAMP ON UPDATE CURRENT_TIMESTAMP')

  `__init__`(timezone=False)

class `sqlalchemy.databases.mysql.` `MSYear`(display_width=None)

  Bases: `sqlalchemy.types.TypeEngine`

  MySQL YEAR type, for single byte storage of years 1901-2155.

  `__init__`(display_width=None)

class `sqlalchemy.databases.mysql.` `MSText`(length=None, **kwargs)

  Bases: `sqlalchemy.databases.mysql._StringType`, `sqlalchemy.types.Text`

  MySQL TEXT type, for text up to 2^16 characters.

  `__init__`(length=None, **kwargs)

    Construct a TEXT.

    Parameters: | length – Optional, if provided the server may optimize storage by substituting the smallest TEXT type sufficient to store `length` characters. charset – Optional, a column-level character set for this string value. Takes precedence to ‘ascii’ or ‘unicode’ short-hand. collation – Optional, a column-level collation for this string value. Takes precedence to ‘binary’ short-hand. ascii – Defaults to False: short-hand for the `latin1` character set, generates ASCII in schema. unicode – Defaults to False: short-hand for the `ucs2` character set, generates UNICODE in schema. national – Optional. If true, use the server’s configured national character set. binary – Defaults to False: short-hand, pick the binary collation type that matches the column’s character set. Generates BINARY in schema. This does not affect the type of data stored, only the collation of character data.

class `sqlalchemy.databases.mysql.` `MSTinyText`(**kwargs)

  Bases: `sqlalchemy.databases.mysql.MSText`

  MySQL TINYTEXT type, for text up to 2^8 characters.

  `__init__`(**kwargs)

    Construct a TINYTEXT.

    Parameters: | charset – Optional, a column-level character set for this string value. Takes precedence to ‘ascii’ or ‘unicode’ short-hand. collation – Optional, a column-level collation for this string value. Takes precedence to ‘binary’ short-hand. ascii – Defaults to False: short-hand for the `latin1` character set, generates ASCII in schema. unicode – Defaults to False: short-hand for the `ucs2` character set, generates UNICODE in schema. national – Optional. If true, use the server’s configured national character set. binary – Defaults to False: short-hand, pick the binary collation type that matches the column’s character set. Generates BINARY in schema. This does not affect the type of data stored, only the collation of character data.

class `sqlalchemy.databases.mysql.` `MSMediumText`(**kwargs)

  Bases: `sqlalchemy.databases.mysql.MSText`

  MySQL MEDIUMTEXT type, for text up to 2^24 characters.

  `__init__`(**kwargs)

    Construct a MEDIUMTEXT.

    Parameters: | charset – Optional, a column-level character set for this string value. Takes precedence to ‘ascii’ or ‘unicode’ short-hand. collation – Optional, a column-level collation for this string value. Takes precedence to ‘binary’ short-hand. ascii – Defaults to False: short-hand for the `latin1` character set, generates ASCII in schema. unicode – Defaults to False: short-hand for the `ucs2` character set, generates UNICODE in schema. national – Optional. If true, use the server’s configured national character set. binary – Defaults to False: short-hand, pick the binary collation type that matches the column’s character set. Generates BINARY in schema. This does not affect the type of data stored, only the collation of character data.

class `sqlalchemy.databases.mysql.` `MSLongText`(**kwargs)

  Bases: `sqlalchemy.databases.mysql.MSText`

  MySQL LONGTEXT type, for text up to 2^32 characters.

  `__init__`(**kwargs)

    Construct a LONGTEXT.

    Parameters: | charset – Optional, a column-level character set for this string value. Takes precedence to ‘ascii’ or ‘unicode’ short-hand. collation – Optional, a column-level collation for this string value. Takes precedence to ‘binary’ short-hand. ascii – Defaults to False: short-hand for the `latin1` character set, generates ASCII in schema. unicode – Defaults to False: short-hand for the `ucs2` character set, generates UNICODE in schema. national – Optional. If true, use the server’s configured national character set. binary – Defaults to False: short-hand, pick the binary collation type that matches the column’s character set. Generates BINARY in schema. This does not affect the type of data stored, only the collation of character data.

class `sqlalchemy.databases.mysql.` `MSString`(length=None, **kwargs)

  Bases: `sqlalchemy.databases.mysql._StringType`, `sqlalchemy.types.String`

  MySQL VARCHAR type, for variable-length character data.

  `__init__`(length=None, **kwargs)

    Construct a VARCHAR.

    Parameters: | charset – Optional, a column-level character set for this string value. Takes precedence to ‘ascii’ or ‘unicode’ short-hand. collation – Optional, a column-level collation for this string value. Takes precedence to ‘binary’ short-hand. ascii – Defaults to False: short-hand for the `latin1` character set, generates ASCII in schema. unicode – Defaults to False: short-hand for the `ucs2` character set, generates UNICODE in schema. national – Optional. If true, use the server’s configured national character set. binary – Defaults to False: short-hand, pick the binary collation type that matches the column’s character set. Generates BINARY in schema. This does not affect the type of data stored, only the collation of character data.

class `sqlalchemy.databases.mysql.` `MSChar`(length, **kwargs)

  Bases: `sqlalchemy.databases.mysql._StringType`, `sqlalchemy.types.CHAR`

  MySQL CHAR type, for fixed-length character data.

  `__init__`(length, **kwargs)

    Construct an NCHAR.

    Parameters: | length – Maximum data length, in characters. binary – Optional, use the default binary collation for the national character set. This does not affect the type of data stored, use a BINARY type for binary data. collation – Optional, request a particular collation. Must be compatible with the national character set.

class `sqlalchemy.databases.mysql.` `MSNVarChar`(length=None, **kwargs)

  Bases: `sqlalchemy.databases.mysql._StringType`, `sqlalchemy.types.String`

  MySQL NVARCHAR type.

  For variable-length character data in the server’s configured national character set.

  `__init__`(length=None, **kwargs)

    Construct an NVARCHAR.

    Parameters: | length – Maximum data length, in characters. binary – Optional, use the default binary collation for the national character set. This does not affect the type of data stored, use a BINARY type for binary data. collation – Optional, request a particular collation. Must be compatible with the national character set.

class `sqlalchemy.databases.mysql.` `MSNChar`(length=None, **kwargs)

  Bases: `sqlalchemy.databases.mysql._StringType`, `sqlalchemy.types.CHAR`

  MySQL NCHAR type.

  For fixed-length character data in the server’s configured national character set.

  `__init__`(length=None, **kwargs)

    Construct an NCHAR. Arguments are:

    Parameters: | length – Maximum data length, in characters. binary – Optional, use the default binary collation for the national character set. This does not affect the type of data stored, use a BINARY type for binary data. collation – Optional, request a particular collation. Must be compatible with the national character set.

class `sqlalchemy.databases.mysql.` `MSVarBinary`(length=None, **kw)

  Bases: `sqlalchemy.databases.mysql._BinaryType`

  MySQL VARBINARY type, for variable length binary data.

  `__init__`(length=None, **kw)

    Construct a VARBINARY. Arguments are:

    Parameter: | length – Maximum data length, in characters.

class `sqlalchemy.databases.mysql.` `MSBinary`(length=None, **kw)

  Bases: `sqlalchemy.databases.mysql._BinaryType`

  MySQL BINARY type, for fixed length binary data

  `__init__`(length=None, **kw)

    Construct a BINARY.

    This is a fixed length type, and short values will be right-padded with a server-version-specific pad value.

    Parameter: | length – Maximum data length, in bytes. If length is not specified, this will generate a BLOB. This usage is deprecated.

class `sqlalchemy.databases.mysql.` `MSBlob`(length=None, **kw)

  Bases: `sqlalchemy.databases.mysql._BinaryType`

  MySQL BLOB type, for binary data up to 2^16 bytes

  `__init__`(length=None, **kw)

    Construct a BLOB. Arguments are:

    Parameter: | length – Optional, if provided the server may optimize storage by substituting the smallest TEXT type sufficient to store `length` characters.

class `sqlalchemy.databases.mysql.` `MSTinyBlob`(length=None, **kw)

  Bases: `sqlalchemy.databases.mysql.MSBlob`

  MySQL TINYBLOB type, for binary data up to 2^8 bytes.

  `__init__`(length=None, **kw)

    Construct a BLOB. Arguments are:

    Parameter: | length – Optional, if provided the server may optimize storage by substituting the smallest TEXT type sufficient to store `length` characters.

class `sqlalchemy.databases.mysql.` `MSMediumBlob`(length=None, **kw)

  Bases: `sqlalchemy.databases.mysql.MSBlob`

  MySQL MEDIUMBLOB type, for binary data up to 2^24 bytes.

  `__init__`(length=None, **kw)

    Construct a BLOB. Arguments are:

    Parameter: | length – Optional, if provided the server may optimize storage by substituting the smallest TEXT type sufficient to store `length` characters.

class `sqlalchemy.databases.mysql.` `MSLongBlob`(length=None, **kw)

  Bases: `sqlalchemy.databases.mysql.MSBlob`

  MySQL LONGBLOB type, for binary data up to 2^32 bytes.

  `__init__`(length=None, **kw)

    Construct a BLOB. Arguments are:

    Parameter: | length – Optional, if provided the server may optimize storage by substituting the smallest TEXT type sufficient to store `length` characters.

class `sqlalchemy.databases.mysql.` `MSEnum`(*enums, **kw)

  Bases: `sqlalchemy.databases.mysql.MSString`

  MySQL ENUM type.

  `__init__`(*enums, **kw)

    Construct an ENUM.

    Example:

    > Column(‘myenum’, MSEnum(“foo”, “bar”, “baz”))

    Arguments are:

    Parameters: | enums – The range of valid values for this ENUM. Values will be quoted when generating the schema according to the quoting flag (see below). strict – Defaults to False: ensure that a given value is in this ENUM’s range of permissible values when inserting or updating rows. Note that MySQL will not raise a fatal error if you attempt to store an out of range value- an alternate value will be stored instead. (See MySQL ENUM documentation.) charset – Optional, a column-level character set for this string value. Takes precedence to ‘ascii’ or ‘unicode’ short-hand. collation – Optional, a column-level collation for this string value. Takes precedence to ‘binary’ short-hand. ascii – Defaults to False: short-hand for the `latin1` character set, generates ASCII in schema. unicode – Defaults to False: short-hand for the `ucs2` character set, generates UNICODE in schema. binary – Defaults to False: short-hand, pick the binary collation type that matches the column’s character set. Generates BINARY in schema. This does not affect the type of data stored, only the collation of character data. quoting – Defaults to ‘auto’: automatically determine enum value quoting. If all enum values are surrounded by the same quoting character, then use ‘quoted’ mode. Otherwise, use ‘unquoted’ mode. ‘quoted’: values in enums are already quoted, they will be used directly when generating the schema. ‘unquoted’: values in enums are not quoted, they will be escaped and surrounded by single quotes when generating the schema. Previous versions of this type always required manually quoted values to be supplied; future versions will always quote the string literals for you. This is a transitional option.

class `sqlalchemy.databases.mysql.` `MSSet`(*values, **kw)

  Bases: `sqlalchemy.databases.mysql.MSString`

  MySQL SET type.

  `__init__`(*values, **kw)

    Construct a SET.

    Example:

        Column('myset', MSSet("'foo'", "'bar'", "'baz'"))

    Arguments are:

    Parameters: | values – The range of valid values for this SET. Values will be used exactly as they appear when generating schemas. Strings must be quoted, as in the example above. Single-quotes are suggested for ANSI compatibility and are required for portability to servers with ANSI_QUOTES enabled. charset – Optional, a column-level character set for this string value. Takes precedence to ‘ascii’ or ‘unicode’ short-hand. collation – Optional, a column-level collation for this string value. Takes precedence to ‘binary’ short-hand. ascii – Defaults to False: short-hand for the `latin1` character set, generates ASCII in schema. unicode – Defaults to False: short-hand for the `ucs2` character set, generates UNICODE in schema. binary – Defaults to False: short-hand, pick the binary collation type that matches the column’s character set. Generates BINARY in schema. This does not affect the type of data stored, only the collation of character data.

class `sqlalchemy.databases.mysql.` `MSBoolean`(*args, **kwargs)

  Bases: `sqlalchemy.types.Boolean`

  MySQL BOOLEAN type.

  `__init__`(*args, **kwargs)